@@ -3,13 +3,12 @@ BEGIN {
   $File::Serialize::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '0.0.1';
-
+$File::Serialize::VERSION = '0.1.0';
 use strict;
 use warnings;
 
 use Class::Load qw/ load_class /;
-use List::Util qw/ pairgrep first none any pairmap /;
+use List::Util 1.41 qw/ pairgrep first none any pairmap /;
 use Path::Tiny;
 
 use parent 'Exporter::Tiny';
@@ -57,6 +56,9 @@ sub _generate_serialize_file {
 
         my $serializer = _serializer($file, $options);
 
+        $file = path( join '.', $file, $serializer->{extensions}[0] )
+            if $options->{add_extension};
+
         $options = $_->($options, 1) for
                     first { $_ }
                     map( { $serializer->{$_} } qw/ options / ), sub { +{} };
@@ -77,6 +79,9 @@ sub _generate_deserialize_file {
 
         my $serializer = _serializer($file, $options);
 
+        $file = path( join '.', $file, $serializer->{extensions}[0] )
+            if $options->{add_extension};
+
         ($options) = map { $_->($options) }
                     first { $_ }
                     map( { $serializer->{$_} } qw/ options / ), sub { +{} };
@@ -120,7 +125,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 0.0.1
+version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -220,6 +225,15 @@ Explicitly provides the serializer to use.
 
     my $data = deserialize_file $path, { format => 'json' };
 
+=item add_extension => $boolean
+
+If true, the canonical extension of the serializing format will be 
+appended to the file. Requires the parameter C<format> to be given as well.
+
+    # will create 'foo.yml', 'foo.json' and 'foo.toml'
+    serialize_file 'foo', $data, { format => $_, add_extension => 1 } 
+        for qw/ yaml json toml /;
+
 =item pretty => $boolean
 
 The serialization will be formatted for human consumption.
